precision highp float;

varying highp vec2 textureCoordinate;
uniform sampler2D inputImageTexture;

uniform float iTime;

const float pi = 4. * atan(1.);
const float ang = (3. - sqrt(5.)) * pi;
const float gamma = 1.8;
const float SAMPLES = 50.0;
const vec2 resolution = vec2(1280.0, 1080.0);

vec3 bokeh(sampler2D samp, vec2 textCoored, vec2 radius, float lod) {
    vec3 col = vec3(0);
    for(float i = 0.; i < SAMPLES; i++) {
        float d = i / SAMPLES;
        vec2 p = vec2(sin(ang * i), cos(ang * i)) * sqrt(d) * radius;
        col += pow(texture2D(samp, textCoored + p, lod).rgb, vec3(1.8));
    }
    return pow(col / SAMPLES, vec3(1. / gamma));
}

void main() {
    vec2 pix = 1. / resolution;
    float r = sin(iTime);
    r *= r * 20.;
    float lod = log2(r / SAMPLES * pi * 5.);
    vec4 textureColor = texture2D(inputImageTexture, textureCoordinate);
    vec4 col = vec4(bokeh(inputImageTexture, textureCoordinate, r * pix, lod), 1.0);
    gl_FragColor = col;
}