precision lowp float;
varying highp vec2 textureCoordinate;
varying highp vec2 textureCoordinate2;
uniform sampler2D inputImageTexture;
uniform sampler2D inputImageTexture2;
uniform lowp float shift;
uniform lowp float height;
uniform lowp float bufferPercent;
uniform int is3D;
const mediump vec3 color = vec3(255.0, 255.0, 255.0);

highp vec3 blend(highp vec3 base, highp vec3 over) {
    return over;
}
highp vec3 blend(highp vec3 base, highp vec3 over, lowp float opacity) {
    return (blend(base, over) * opacity + base * (1.0 - opacity));
}

highp float overlayblend(highp float target, highp float blend) {
    highp float result;
    if (target > 0.5) result = (1.0 - (1.0-2.0*(target-0.5)) * (1.0-blend));
    else result = ((2.0*target) * blend);
    return result;
}
highp float softlightblend(highp float target, highp float blend) {
    highp float result;
    if (target > 0.5) result = (1.0 - (1.0-target) * (1.0-(blend - 0.5)));
    else result = (target * (blend + 0.5));
    return result;
}
highp vec4 softlightblend(highp vec4 target, highp vec4 blend) {
    highp vec4 result;
    result.r = softlightblend(target.r, blend.r);
    result.g = softlightblend(target.g, blend.g);
    result.b = softlightblend(target.b, blend.b);
    result.a = 1.0;
    return result;
}
highp vec4 overlayblend(highp vec4 target, highp vec4 blend) {
    highp vec4 result;
    result.r = overlayblend(target.r, blend.r);
    result.g = overlayblend(target.g, blend.g);
    result.b = overlayblend(target.b, blend.b);
    result.a = 1.0;
    return result;
}
highp vec4 darkenblend(highp vec4 target, highp vec4 blend) {
    highp vec4 result;
    result = vec4(min(blend.rgb * target.a, target.rgb * blend.a) + blend.rgb * (1.0 - target.a) + target.rgb * (1.0 - blend.a), 1.0);
    return result;
}
highp vec4 multiplyblend(highp vec4 target, highp vec4 blend) {
    highp vec4 result;
    result = blend * target + blend * (1.0 - target.a) + target * (1.0 - blend.a);
    return result;
}

void main()
{

    lowp vec4 sky;
    lowp vec4 sky2;
    lowp vec2 sky2Coords;
    lowp float coordX = abs(textureCoordinate.x + (0.4 * -shift));
    lowp float coordY = textureCoordinate.y + (0.1);

    if (coordY  >= 1.0){

        coordY = 1.0 - mod(coordY, 1.0);
    }

    sky2Coords = vec2(coordX, coordY);

    sky2Coords[0] = mod(sky2Coords[0], 1.0);
    sky2Coords[1] = mod(sky2Coords[1], 1.0);

    sky = texture2D(inputImageTexture, textureCoordinate);
    sky2 = texture2D(inputImageTexture, sky2Coords);

    lowp vec4 skyOut;

    if (is3D == 1) {

        skyOut = softlightblend(sky, sky2);

    } else {

        skyOut = sky;
    }

    vec4 tex1 = vec4(color / 255.0, 1.0);
    tex1.rgb /= tex1.a;
    mediump vec4 tex2 = skyOut;
    float bufferPercent = bufferPercent / 100.0;
    float nHeight = 1.0 - (height / 100.0);
    float upperVal = nHeight + bufferPercent;
    vec4 outa = tex1;
    if (textureCoordinate.y <= upperVal && textureCoordinate.y >= nHeight) {
        vec2 lower = vec2(0.0, nHeight);
        vec2 higher = vec2(0.0, upperVal);
        vec2 dir = higher - lower;
        float lenSq = dot(dir, dir);
        vec2 relCoords = textureCoordinate - lower;
        float t = dot (relCoords, dir) / lenSq;
        outa = vec4(blend(tex2.rgb, tex1.rgb, t), 1.0);
    } else if (textureCoordinate.y > upperVal){
        outa = tex1;
    } else {
        outa = tex2;
    }
    gl_FragColor = outa;
}